@@ -3,7 +3,7 @@ import numpy as np
 import pandas as pd
 
 
-def fis_tool_clean_df_columns(df):
+def fis_tools_clean_df_columns(df):
     for col in df.columns:
         new_col = col.lower()
         new_col = new_col.replace(" ", "_")
@@ -18,14 +18,14 @@ def fis_tool_clean_df_columns(df):
         df.rename({col: new_col}, axis=1, inplace=True)
     return df
     
-def fis_tool_frec_cat(df_cat):
+def fis_tools_frec_cat(df_cat):
     resultado = df_cat.apply(lambda x: x.value_counts(normalize = True)).T.stack()\
                 .to_frame().reset_index()\
                 .rename(columns={'level_0':'Variable','level_1':'Valor',0: "Frecuencia"})\
                 .sort_values(by = ['Variable','Frecuencia'])
     return(resultado)
     
-def fis_tool_stats_cont(df_cont):
+def fis_tools_stats_cont(df_cont):
     #Calculamos describe
     estadisticos = df_cont.describe().T
     #Añadimos la mediana
@@ -91,7 +91,7 @@ def fis_tools_quitar_tildes(palabra):
     #Aplicamos el traductor y devolvemos la palabra limpia
     return(palabra.translate(traductor))
     
-def fis_tools_strong_corr(df, lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
+def fis_tools_pre_strong_corr(df, lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
     #Calcula la matriz de correlación
     c = x.corr().abs()
     #Lo pasa todo a filas
@@ -106,7 +106,7 @@ def fis_tools_strong_corr(df, lim_inf = 0.3, lim_sup = 1,drop_dupli=True):
     #Devuelve la salida
     return(c)
     
-def fis_tools_ranking_mi(mutual_selector, predictors_df, modo = 'tabla'):
+def fis_tools_pre_ranking_mi(mutual_selector, predictors_df, modo = 'tabla'):
     #Maqueta el ranking
     ranking_mi = pd.DataFrame(mutual_selector, index = predictors_df.columns).reset_index()
     ranking_mi.columns = ['variable','importancia_mi']
@@ -118,4 +118,9 @@ def fis_tools_ranking_mi(mutual_selector, predictors_df, modo = 'tabla'):
     else:
         g = ranking_mi[0:15].importancia_mi.sort_values().plot.barh()
         g.set_yticklabels(ranking_mi[0:15].sort_values(by = 'importancia_mi').variable)
-        return(g)
\ No newline at end of file
+        return(g)
+ 
+ def fis_tools_pre_ranking_per(predictoras,permutacion):
+    ranking_per = pd.DataFrame({'variable': predictoras.columns, 'importancia_per': permutacion.importances_mean}).sort_values(by = 'importancia_per', ascending = False)
+    ranking_per['ranking_per'] = np.arange(0,ranking_per.shape[0])
+    return(ranking_per)
\ No newline at end of file
